@@ -1,19 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 1999,2000 Kurt Granroth <granroth@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999, 2000 Kurt Granroth <granroth@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kstandardaction.h"
@@ -26,12 +15,12 @@
 #include <QLayout>
 #include <QMainWindow>
 #include <QMenuBar>
-#include <kaboutdata.h>
-#include <klocalizedstring.h>
-#include <kstandardshortcut.h>
-#include <kacceleratormanager.h>
+#include <KAboutData>
+#include <KLocalizedString>
+#include <KStandardShortcut>
+#include <KAcceleratorManager>
 
-#include "kdualaction.h"
+#include <KDualAction>
 #include "kpastetextaction.h"
 
 namespace KStandardAction
